#!/usr/bin/env python3
# vim: set ft=python fileencoding=utf-8 tw=72:
"""
A blog-oriented static web content generator from Markdown to HTML5.

    :author: J A Corbal
    :copyright: © 2012-2020, J. A. Corbal
    :license: MIT
"""

from pynfact.cli import main


if __name__ == '__main__':
    main()

