{% extends "base.html.j2" %}
{% block title %}{% trans %}Blog{% endtrans %}{% endblock %}

{% block body %}

<section class="overview">
    <section class="hyphenate prettify">
    {%- if entries %}
        {%- for entry in entries %}
        <div class="entry-overview">
            <div class="info">
                <span class="date">{{ entry.date }}</span><br><span
                    class="category"><a
                        href="{{ entry.category_uri }}"
                        title="{{ entry.category }}">{{ entry.category }}</a></span>
            </div>
            <div class="detail{%- if not entry.summary %} no-summary{%- endif %}">
                <a href=" {{entry.uri }}"
                   title="{{ entry.title | striptags}}"
                   ><strong>{{ entry.title }}</strong></a>{%- if
                   entry.summary %}&nbsp;&mdash;&nbsp;<div
                   class="summary">{{ entry.summary }}</div>{%- endif %}
            </div>
        </div>
        {%- endfor %}

        {%- if total_pages > 1 %}
        <!-- PAGER -->
        <div class="paginator">
            {%- if cur_page == 1 %}
            <span class="disabled">&laquo;&nbsp;{% trans %}Previous{% endtrans %}</span>
            {%- endif %}
            {%- if cur_page == 2 %}
            <span><a href="{{ base_uri }}"
                     title="{% trans %}Previous{% endtrans %}"
                    >&laquo;&nbsp;{% trans %}Previous{% endtrans %}</a></span>
            {%- endif %}
            {%- if cur_page > 2 %}
            <span><a href="{{ base_uri }}page/{{ cur_page - 1 }}"
                     title="{% trans %}Previous{% endtrans %}"
                    >&laquo;&nbsp;{% trans %}Previous{% endtrans %}</a></span>
            {%- endif %}
            <span class="separator">&mdash;</span>

            <strong class="page_number">{{ cur_page }}</strong>

            <span class="separator">&mdash;</span>
            {%- if cur_page < total_pages %}
            <span><a href="{{ base_uri }}page/{{ cur_page + 1 }}"
                     title="{% trans %}Next{% endtrans %}"
                    >{% trans %}Next{% endtrans %}&nbsp;&raquo;</a></span>
            {%- else %}
            <span class="disabled">{% trans %}Next{% endtrans %}&nbsp;&raquo;</span>
            {%- endif %}
        </div>
        {%- endif %}
    {%- else %}
    <!-- No entries -->
    <h2>nichts, nada, niente, nothing, nix, rien, nihil, niks,
        asgjë, ništa, nic, nič, nimic, noget, niets, nenio, miski,
        wala, mikään ei, res, semmi, ekkert, nekas, niekas,
        ingenting, không, 何も, 무, 無, ничего, ништо, ништа,
        нічога, нічого, ոչինչ, нищо, τίποτα,
        <span class="rtl">שום דבר</span>,
        <span class="rtl">لا شيء</span>,
        Ø, {},...</h2>
    {%- endif %}

    </section>
</section>

{% endblock %}

