#!/usr/bin/env python3
# vim: set ft=python fileencoding=utf-8 tw=72:
#
########################################################################
# The MIT License (MIT)
#
# Copyright (c) 2012-2020, J. A. Corbal
#
# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# “Software”), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
########################################################################
"""
A blog-oriented static web content generator from Markdown to HTML5.

    :author: J A Corbal
    :copyright: © 2012-2020, J. A. Corbal
    :license: MIT
"""
__author__ = "J. A. Corbal"
__copyright__ = "Copyright 2012-2020, J. A. Corbal"
__email__ = "jacorbal@gmail.com"
__license__ = "MIT"
__maintainer__ = "J. A. Corbal"
__status__ = "Production"
__version_info__ = ('1', '3', '1a2')
__version__ = '.'.join(__version_info__)

