{% extends "base.html.j2" %}
{% block index %}
        <meta name="robots" content="noindex, nofollow, noodp, noydir, noarchive, noimageindex">
        <meta name="googlebot" content="noarchive, nosnippet, noindex, nofollow, noodp, noimageindex"><!--google-->
{% endblock %}
{% block metadescription %} ({% trans %}Categories{% endtrans %}){% endblock %}
{% block title %}{% trans %}Entries categorized as{% endtrans %} «{{ category_name }}»{% endblock %}

{% block body %}

<article class="page">
    <header>
        <h1>{% trans %}Entries categorized{% endtrans %}
            <q class="nowrap">{{ category_name }}</q></h1>
    </header>

    <section class="page hyphenate prettify">
        {%- if entries %}
        <ul>
            {%- for entry in entries %}
            <li><a href="{{ base_uri}}{{ entry.uri }}"
                   title="{{ entry.title | striptags }}">{{ entry.title }}</a>,
                <!-- {% trans %}published on{% endtrans %} -->
                {{ entry.date }}
            {%- endfor %}
        </ul>
        {%- endif %}
    </section>

</article>

{% endblock %}

